==> radiance-ui-2.0.19.tgz: package/lib/shared-components/field/index.js <==
import { jsx as ___EmotionJSX } from "@emotion/core";

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

import PropTypes from 'prop-types';
import React from 'react';
import { TransitionGroup } from 'react-transition-group';
import { FieldContainer, Label, InputContainer, Textarea, Input, ErrorItem, HintItem, HelperList } from './style';
import ErrorIcon from '../../svgs/icons/error-icon.svg';
import HelperTransition from './helperTransition';

var Field =
/*#__PURE__*/
function (_React$Component) {
  _inherits(Field, _React$Component);

  function Field() {
    var _getPrototypeOf2;

    var _this;

    _classCallCheck(this, Field);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _possibleConstructorReturn(this, (_getPrototypeOf2 = _getPrototypeOf(Field)).call.apply(_getPrototypeOf2, [this].concat(args)));

    _this.formatError = function (errorValue) {
      return Array.isArray(errorValue) ? errorValue.join(', ') : errorValue;
    };

    return _this;
  }

  _createClass(Field, [{
    key: "render",
    value: function render() {
      var _this2 = this;

      var _this$props = this.props,
          inputChild = _this$props.children,
          disabled = _this$props.disabled,
          errors = _this$props.errors,
          hintMessage = _this$props.hintMessage,
          label = _this$props.label,
          labelFor = _this$props.labelFor;
      var htmlFor = labelFor || label;
      var errorKeys = Object.keys(errors);
      var showErrors = errorKeys.length > 0;
      return ___EmotionJSX(FieldContainer, null, !!label && ___EmotionJSX(Label, {
        htmlFor: htmlFor,
        disabled: disabled
      }, label), ___EmotionJSX(InputContainer, {
        showErrors: showErrors
      }, ___EmotionJSX(ErrorIcon, null), React.cloneElement(inputChild, {
        disabled: disabled
      }), ___EmotionJSX(TransitionGroup, {
        component: HelperList
      }, !!hintMessage && ___EmotionJSX(HelperTransition, {
        key: "hint-message"
      }, ___EmotionJSX(HintItem, null, hintMessage)), showErrors && errorKeys.map(function (key) {
        return ___EmotionJSX(HelperTransition, {
          key: key
        }, ___EmotionJSX(ErrorItem, null, _this2.formatError(errors[key])));
      }))));
    }
  }]);

  return Field;
}(React.Component);

Field.propTypes = {
  children: PropTypes.element.isRequired,
  disabled: PropTypes.bool,
  errors: PropTypes.objectOf(PropTypes.oneOfType([PropTypes.string, PropTypes.arrayOf(PropTypes.string)])),
  hintMessage: PropTypes.string,
  label: PropTypes.string,
  labelFor: PropTypes.string
};
Field.defaultProps = {
  disabled: false,
  errors: {},
  hintMessage: '',
  label: ''
};
Field.Textarea = Textarea;
Field.Input = Input;
export default Field;

==> radiance-ui-2.0.23.tgz: package/lib/shared-components/field/index.js <==
import { jsx as ___EmotionJSX } from "@emotion/core";

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

import PropTypes from 'prop-types';
import React from 'react';
import { FieldContainer, Label, InputContainer, Textarea, Input, HintItem } from './style';
import ErrorIcon from '../../svgs/icons/error-icon.svg';
import BulkErrors from '../bulkErrors';

var Field =
/*#__PURE__*/
function (_React$Component) {
  _inherits(Field, _React$Component);

  function Field() {
    _classCallCheck(this, Field);

    return _possibleConstructorReturn(this, _getPrototypeOf(Field).apply(this, arguments));
  }

  _createClass(Field, [{
    key: "render",
    value: function render() {
      var _this$props = this.props,
          inputChild = _this$props.children,
          disabled = _this$props.disabled,
          errors = _this$props.errors,
          hintMessage = _this$props.hintMessage,
          label = _this$props.label,
          labelFor = _this$props.labelFor;
      var htmlFor = labelFor || label;
      var errorKeys = Object.keys(errors);
      var showErrors = errorKeys.length > 0;
      return ___EmotionJSX(FieldContainer, null, !!label && ___EmotionJSX(Label, {
        htmlFor: htmlFor,
        disabled: disabled
      }, label), ___EmotionJSX(InputContainer, {
        showErrors: showErrors
      }, ___EmotionJSX(ErrorIcon, null), React.cloneElement(inputChild, {
        disabled: disabled
      }), !!hintMessage && ___EmotionJSX(HintItem, null, hintMessage), ___EmotionJSX(BulkErrors, {
        errors: errors
      })));
    }
  }]);

  return Field;
}(React.Component);

Field.propTypes = {
  children: PropTypes.element.isRequired,
  disabled: PropTypes.bool,
  errors: PropTypes.objectOf(PropTypes.oneOfType([PropTypes.string, PropTypes.arrayOf(PropTypes.string)])),
  hintMessage: PropTypes.string,
  label: PropTypes.string,
  labelFor: PropTypes.string
};
Field.defaultProps = {
  disabled: false,
  errors: {},
  hintMessage: '',
  label: ''
};
Field.Textarea = Textarea;
Field.Input = Input;
export default Field;
